import React, { useState, useEffect } from 'react';
import { Box, Typography, Button, Modal, Container } from '@mui/material';
import { useNavigate } from 'react-router-dom';
import { useTheme } from '@mui/material/styles';
import './Home.css'; // Import the CSS file

const Home = () => {
 const [open, setOpen] = useState(true); // Assuming the modal should be open by default
 const navigate = useNavigate();
 const theme = useTheme();

 // Simulate checking if the user is a returning user
 const isReturningUser = false; // This should be replaced with actual logic

 const handleClose = () => {
    setOpen(false);
 };

 const handleNavigate = () => {
    if (isReturningUser) {
      navigate('/login');
    } else {
      navigate('/register');
    }
 };

 useEffect(() => {
    // This is where you would check if the user is a returning user
    // For demonstration, we're setting isReturningUser to false
    // In a real application, you would replace this with actual logic
    // For example, checking localStorage or a backend service
 }, []);

 return (
    <Container maxWidth="sm">
      <Modal
        open={open}
        onClose={handleClose}
        aria-labelledby="home-modal-title"
        aria-describedby="home-modal-description"
      >
        <Box
          sx={{
            position: 'absolute',
            top: '50%',
            left: '50%',
            transform: 'translate(-50%, -50%)',
            width: 400,
            bgcolor: theme.palette.background.paper,
            boxShadow: 24,
            p: 4,
          }}
        >
          <Typography id="home-modal-title" variant="h6" component="h2">
            RadioLogger
          </Typography>
          <Typography id="home-modal-description" variant="body1">
            A software tool that helps radio enthusiasts keep track of their radio communications and log their listening experiences.
          </Typography>
          <Button variant="contained" color="primary" onClick={handleNavigate}>
            Go to {isReturningUser ? 'Login' : 'Register'}
          </Button>
        </Box>
      </Modal>
    </Container>
 );
};

export default Home;