import React, { useState, useRef, useEffect, useMemo, useCallback } from 'react';
import { Button, TextField, Box, Typography } from '@mui/material';
import { useNavigate } from 'react-router-dom'; // Import useNavigate from react-router-dom
import './Login.css'; // Import the CSS file

const Login = () => {
 const [username, setUsername] = useState('');
 const [password, setPassword] = useState('');
 const usernameRef = useRef();
 const passwordRef = useRef();
 const navigate = useNavigate(); // Use useNavigate instead of useHistory

 const handleLogin = (e) => {
    e.preventDefault();
    const API_V = 'http://localhost:3001/api/v1';
    const END_POINT = '/login';
    const data = {
      username: username,
      password: password,
    };
    const headers = {
      "Content-type": "application/json; charset=UTF-8",
      'Access-Control-Allow-Origin': '*',
    };

    const options = {
      method: 'POST',
      headers: headers,
      body: JSON.stringify(data),
    };

    fetch(`${API_V}${END_POINT}`, options)
      .then(response => response.json())
      .then(data => {
        if (data.data) {
          console.log('Welcome');
          localStorage.setItem('accessToken', data.accessToken);
          navigate('/dashboard'); // Use navigate to redirect to dashboard
        }
      })
      .catch(err => console.log(err));
 };

 return (
    <Box className="login_box" sx={{
      backgroundColor: 'rgba(0, 0, 0, 0.5)',
      position: 'absolute',
      top: '50%',
      left: '50%',
      width: 400,
      padding: 4,
      transform: 'translate(-50%, -50%)',
      boxSizing: 'border-box',
      boxShadow: '0px 15px 25px rgba(0, 0, 0, 0.6)',
      borderRadius: 10,
    }}>
      <Typography variant="h4" component="h2" gutterBottom>
        Login
      </Typography>
      <TextField
        fullWidth
        margin="normal"
        label="Username"
        variant="outlined"
        value={username}
        onChange={(e) => setUsername(e.target.value)}
        inputRef={usernameRef}
      />
      <TextField
        fullWidth
        margin="normal"
        label="Password"
        type="password"
        variant="outlined"
        value={password}
        onChange={(e) => setPassword(e.target.value)}
        inputRef={passwordRef}
      />
      <Button variant="contained" color="primary" onClick={handleLogin}>
        Submit
      </Button>
    </Box>
 );
};

export default Login;