import React, { useState, useRef, useEffect, useCallback } from 'react';
import { Box, Card, CardContent, Typography, Button, IconButton, Grid, Carousel, List, ListItem, ListItemIcon, ListItemText, Modal, TextField } from '@mui/material';
import { useNavigate } from 'react-router-dom';
import { Edit as EditIcon, Message as MessageIcon, Follow as FollowIcon, Favorite as LikeIcon, Share as ShareIcon, Email as EmailIcon, Language as WebsiteIcon } from '@mui/icons-material';

const Profile = () => {
 const [open, setOpen] = useState(false);
 const navigate = useNavigate();
 const messageButtonRef = useRef();

 const handleOpen = () => setOpen(true);
 const handleClose = () => setOpen(false);

 const handleMessage = useCallback(async () => {
    try {
      const response = await fetch('/message', { method: 'GET' });
      if (response.ok) {
        const data = await response.json();
        console.log(data);
      } else {
        console.error('Error fetching messages:', response.statusText);
      }
    } catch (error) {
      console.error('Error sending message request:', error);
    }
 }, []);

 useEffect(() => {
    if (messageButtonRef.current) {
      messageButtonRef.current.addEventListener('click', handleMessage);
    }
    return () => {
      if (messageButtonRef.current) {
        messageButtonRef.current.removeEventListener('click', handleMessage);
      }
    };
 }, [handleMessage]);

 return (
    <Box sx={{ padding: 4 }}>
      <Grid container spacing={2}>
        <Grid item xs={12} md={4}>
          <Card>
            <CardContent>
              <img src="https://via.placeholder.com/150" alt="Profile Picture" style={{ width: '100%', borderRadius: '50%' }} />
              <Typography variant="h5" component="h2">Full Name</Typography>
              <Typography variant="subtitle1" color="textSecondary">Call Sign</Typography>
              <Typography variant="body1">Location</Typography>
              <Typography variant="body1">Antenna</Typography>
              <Typography variant="body1">Radio Rigs</Typography>
              <Typography variant="body1">Transceivers</Typography>
              <Typography variant="body1">Receivers</Typography>
              <Box sx={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center' }}>
                <Button variant="outlined" color="secondary" startIcon={<FollowIcon />}>Follow</Button>
                <Button variant="outlined" color="secondary" startIcon={<MessageIcon />} ref={messageButtonRef}>Message</Button>
                <Button variant="outlined" color="secondary" startIcon={<LikeIcon />}>Like</Button>
                <IconButton color="secondary" onClick={handleOpen}><EditIcon /></IconButton>
                <IconButton color="secondary"><ShareIcon /></IconButton>
              </Box>
            </CardContent>
          </Card>
        </Grid>
        <Grid item xs={12} md={8}>
          {/* About Me, Social Media, and Photos sections */}
        </Grid>
      </Grid>
      <Modal
        open={open}
        onClose={handleClose}
        aria-labelledby="edit-profile-modal-label"
        aria-describedby="edit-profile-modal-description"
      >
        <Box sx={{ position: 'absolute', top: '50%', left: '50%', transform: 'translate(-50%, -50%)', width: 400, bgcolor: 'background.paper', boxShadow: 24, p: 4 }}>
          <Typography id="edit-profile-modal-label" variant="h6" component="h2">Edit Profile</Typography>
          <TextField label="Full Name" fullWidth margin="normal" />
          <TextField label="Call Sign" fullWidth margin="normal" />
          <TextField label="Location" fullWidth margin="normal" />
          <Button variant="contained" color="primary" onClick={handleClose}>Save changes</Button>
        </Box>
      </Modal>
    </Box>
 );
};

export default Profile;